function exp=gamkcorrdimcurve(data);
% Plots dependency of th correlation dimension from the embedding dimension
% (Faure&Korn)
% Copyright Alexander Maye, University Medical Center Hamburg, 2007


dims = 11;
step = 6;
startdim = 3;
psname = 'gacorrdimcurve.eps';

for i=1:length(data)
  fprintf('\n%s ', data{i}.name );
  times = data{i}.times;
  for j=1:size(times,2);
    fprintf('%d ', j);
    t = times(:,j)/20;
    t = t(find(t>0));
    isit=circshift(t,[-1 0]) - t;
    isi=isit(1:end-1,:);
    for dim = 1:dims
      v = embed( isi, startdim+dim*step );
      exp(j,dim,i) = corrdim1single(v);
    end
  end
end

figure('PaperPositionMode','manual', 'PaperUnits','centimeters',...
'PaperPosition', [0 0 15 15]);
set(gca,'FontSize',7);

[y,x] = meshgrid([1:length(data)], startdim+1:step:startdim+dims*step);
m = mean(exp);
y = reshape(m,dims,length(data));
s = sqrt(var(exp)./size(exp,1));
e = reshape(s,dims,length(data));
errorbar(x(:,1), y(:,1), e(:,1), '-o');
hold('on');
errorbar(x(:,2), y(:,2), e(:,2), '-sg');
errorbar(x(:,3), y(:,3), e(:,3), '-dr');
errorbar(x(:,4), y(:,4), e(:,4), '-*c');
xlabel('embedding dimensionality m');
ylabel('correlation dimension \nu');
for i=1:length(data)
  l{i} = data{i}.name;
end
legend(l,'Location','NW');
drawnow;
print('-depsc2', psname);
fprintf('\n');
disp(['Written ' psname]);
