function gmalevyandexponential(data);
% Computes mu in P(isi)=isi^(-mu)
% Concatenates ISIs of all animals in each class
% Copyright Alexander Maye, University Medical Center Hamburg, 2007

psname = 'gmalevy+exp-loglog.ps';
system(['rm ' psname]);
minLength = 10;

for i=1:length(data)
  fprintf('\n%s ', data{i}.name );
  times = data{i}.times;
  gmaisi = [];
  for j=1:size(times,2);
    t = times(:,j)/20;
    t = t(find(t>0));
    isi = diff(t);
    if length(isi) < minLength
      % generate sufficient number of trials with the same statistics by repetitive
      % sampling from the original data
      idx = round((length(isi)-1)*rand(1, minLength))+1;
      isi1 = isi(idx);
      isi = isi1;
    end

    gmaisi = [gmaisi; isi];
  end

  logbinwidth = 0.2;
  logbins = [0.7:logbinwidth:3]';
  logedges = [logbins(1)-logbinwidth/2; logbins+logbinwidth/2];
  logedges = exp(logedges);
  geomcenters = logedges(1:end-1) + diff(logedges)/2;
  logn = histc(gmaisi,logedges);
  logn = logn(1:end-1);
  
  % Log-log plot (Check for power-law tails (Levy))
  subplot(length(data),2,(i-1)*2+1);
  valid = find(logn>0);
  p = polyfit(log(geomcenters(valid)),log(logn(valid)),1);
  loglog(geomcenters, logn, 'o-', ...
    geomcenters, exp(polyval(p, log(geomcenters))));

  xlim([logedges(1) logedges(end)]);
  mu = p(1);
  t = sprintf(' \\mu=%f', mu);
  set(gca,'FontSize',7);
  title([data{i}.name ': ' t]);

  % Log-linear plot (check against exponential distribution)
  edges = [2:20]';
  n = histc(gmaisi,edges);
  mu = expfit(gmaisi);
  subplot(length(data),2,i*2);
  semilogy(edges(1:end-1)+0.5, n(1:end-1), 'o-', edges(1:end-1)+0.5, ...
    exppdf(edges(1:end-1)+0.5, mu)*length(gmaisi));
  t = sprintf(' m=%f', mu);
  set(gca,'FontSize',7);
  title([data{i}.name ': ' t]);
  if i==length(data)
    legend('Data', 'Fit');
    xlabel('ISI [s]');
    ylabel('Number of ocurrences');
  end
end
orient('tall');
print('-dpsc', psname);
disp(' ');
disp(['Written ' psname]);
