function result = rmsfd(data);
% Computes root mean square fluctuation of displacement F(t) 
% (used, e.g. inViswanathan et al, Nature, 1996)
% Copyright Alexander Maye, University Medical Center Hamburg, 2007

minSize = 30; % min number of samples
maxt = 100; % max t in F(t)

for i=1:length(data)
  fprintf('\n%s\n', data{i}.name );
  times = data{i}.times;
  for j=1:size(times,2);
    fprintf(' %d', j);
    t = times(:,j)/20;
    t = t(find(t>0));
    isi = diff(t);
    y = cumsum(isi);
    F = [];
    t = 1:min(length(y)-minSize-1, maxt);
    for k = 1:length(t)
      dy = y(1+t(k):end) - y(1:end-t(k));
      F(k) = sqrt(mean(dy.^2) - (mean(dy))^2);
    end
    p = polyfit(log(t),log(F),1);
    subplot(length(data), size(times,2), (i-1)*size(times,2)+j);
    loglog(t, F, t, exp(polyval(p,log(t))));
    title([data{i}.name ' ' int2str(j) ' ' num2str(p(1))]);
    drawnow;
    result(j,i) = p(1);
  end
  fprintf(' %f +- %f\n', mean(result(:,i)), std(result(:,i)));
end
fprintf('\n');
