function [pos,ngda] = trace( data );
% Reconstructs 2D flight traces and computes net to gross displacement
% ratio  (Coughlin et al.)
% Copyright Alexander Maye, University Medical Center Hamburg, 2007

% turning angle
deg = 30;

cols = maxCols(data);

figure('PaperPositionMode','manual', 'PaperUnits','centimeters',...
'PaperPosition', [0 0 20 5]);
set(gca,'FontSize',7);

for i=1:length(data)
  fprintf('\n%s ', data{i}.name );
  times = data{i}.times;
  dirs = data{i}.dirs;
  for j=1:size(times,2);
    fprintf('%d ', j);
    t = times(:,j)/20;
    ind = find(t>0);
    t = t(ind);
    direction = dirs(:,j);
    direction = direction(ind);
    
    pos = zeros(length(t), 2);
    dir = 0;
    for k = 1:length(t)-1;
      if direction(k)==1
        dir = dir + deg/180*pi;
      else
        dir = dir - deg/180*pi;
      end
      pos(k+1,1) = pos(k,1) + cos(dir)*(t(k+1)-t(k));
      pos(k+1,2) = pos(k,2) + sin(dir)*(t(k+1)-t(k));
    end
  
    subplot(length(data),cols,(i-1)*cols+j);
    plot(pos(:,1),pos(:,2));
    set(gca,'XTickLabel',{}, 'YTickLabel',{});
    xlim([-200 200]);
    ylim([-200 200]);
    
    % Compute NGDA
    d = pos(2:end,:) - pos(1:end-1,:);
    d = sqrt(d(:,1).^2 + d(:,2).^2);
    ngda(i,j) = norm(pos(end,:)) / sum(d);
%    title(num2str(ngda(i,j)));
  end
end
fprintf('\n');
print( '-depsc2', '-r600', ['trace-' num2str(deg) '.eps']);
ngda = ngda';
